# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetNetworkPoliciesResult',
    'AwaitableGetNetworkPoliciesResult',
    'get_network_policies',
    'get_network_policies_output',
]

@pulumi.output_type
class GetNetworkPoliciesResult:
    """
    A collection of values returned by GetNetworkPolicies.
    """
    def __init__(__self__, id=None, network_policies=None, region=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if network_policies and not isinstance(network_policies, list):
            raise TypeError("Expected argument 'network_policies' to be a list")
        pulumi.set(__self__, "network_policies", network_policies)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="networkPolicies")
    def network_policies(self) -> Sequence['outputs.GetNetworkPoliciesNetworkPolicyResult']:
        """
        The network policies in the account
        """
        return pulumi.get(self, "network_policies")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")


class AwaitableGetNetworkPoliciesResult(GetNetworkPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkPoliciesResult(
            id=self.id,
            network_policies=self.network_policies,
            region=self.region)


def get_network_policies(region: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkPoliciesResult:
    """
    A network policy data source. This can be used to get information about all network policies in Materialize.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_network_policies()
    ```


    :param _builtins.str region: The region in which the resource is located.
    """
    __args__ = dict()
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getNetworkPolicies:GetNetworkPolicies', __args__, opts=opts, typ=GetNetworkPoliciesResult).value

    return AwaitableGetNetworkPoliciesResult(
        id=pulumi.get(__ret__, 'id'),
        network_policies=pulumi.get(__ret__, 'network_policies'),
        region=pulumi.get(__ret__, 'region'))
def get_network_policies_output(region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkPoliciesResult]:
    """
    A network policy data source. This can be used to get information about all network policies in Materialize.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_network_policies()
    ```


    :param _builtins.str region: The region in which the resource is located.
    """
    __args__ = dict()
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('materialize:index/getNetworkPolicies:GetNetworkPolicies', __args__, opts=opts, typ=GetNetworkPoliciesResult)
    return __ret__.apply(lambda __response__: GetNetworkPoliciesResult(
        id=pulumi.get(__response__, 'id'),
        network_policies=pulumi.get(__response__, 'network_policies'),
        region=pulumi.get(__response__, 'region')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RoleParameterArgs', 'RoleParameter']

@pulumi.input_type
class RoleParameterArgs:
    def __init__(__self__, *,
                 role_name: pulumi.Input[_builtins.str],
                 variable_name: pulumi.Input[_builtins.str],
                 variable_value: pulumi.Input[_builtins.str],
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RoleParameter resource.
        :param pulumi.Input[_builtins.str] role_name: The name of the role to grant privilege to.
        :param pulumi.Input[_builtins.str] variable_name: The name of the session variable to modify.
        :param pulumi.Input[_builtins.str] variable_value: The value to assign to the session variable.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        """
        pulumi.set(__self__, "role_name", role_name)
        pulumi.set(__self__, "variable_name", variable_name)
        pulumi.set(__self__, "variable_value", variable_value)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the role to grant privilege to.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "role_name", value)

    @_builtins.property
    @pulumi.getter(name="variableName")
    def variable_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the session variable to modify.
        """
        return pulumi.get(self, "variable_name")

    @variable_name.setter
    def variable_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "variable_name", value)

    @_builtins.property
    @pulumi.getter(name="variableValue")
    def variable_value(self) -> pulumi.Input[_builtins.str]:
        """
        The value to assign to the session variable.
        """
        return pulumi.get(self, "variable_value")

    @variable_value.setter
    def variable_value(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "variable_value", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _RoleParameterState:
    def __init__(__self__, *,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 role_name: Optional[pulumi.Input[_builtins.str]] = None,
                 variable_name: Optional[pulumi.Input[_builtins.str]] = None,
                 variable_value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RoleParameter resources.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] role_name: The name of the role to grant privilege to.
        :param pulumi.Input[_builtins.str] variable_name: The name of the session variable to modify.
        :param pulumi.Input[_builtins.str] variable_value: The value to assign to the session variable.
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)
        if variable_name is not None:
            pulumi.set(__self__, "variable_name", variable_name)
        if variable_value is not None:
            pulumi.set(__self__, "variable_value", variable_value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the role to grant privilege to.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role_name", value)

    @_builtins.property
    @pulumi.getter(name="variableName")
    def variable_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the session variable to modify.
        """
        return pulumi.get(self, "variable_name")

    @variable_name.setter
    def variable_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "variable_name", value)

    @_builtins.property
    @pulumi.getter(name="variableValue")
    def variable_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value to assign to the session variable.
        """
        return pulumi.get(self, "variable_value")

    @variable_value.setter
    def variable_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "variable_value", value)


@pulumi.type_token("materialize:index/roleParameter:RoleParameter")
class RoleParameter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 role_name: Optional[pulumi.Input[_builtins.str]] = None,
                 variable_name: Optional[pulumi.Input[_builtins.str]] = None,
                 variable_value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a system parameter in Materialize.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # ALTER ROLE some_role SET transaction_isolation = 'strict serializable';
        example_role = materialize.Role("exampleRole")
        example_role_parameter = materialize.RoleParameter("exampleRoleParameter",
            role_name=example_role.name,
            variable_name="transaction_isolation",
            variable_value="strict serializable")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] role_name: The name of the role to grant privilege to.
        :param pulumi.Input[_builtins.str] variable_name: The name of the session variable to modify.
        :param pulumi.Input[_builtins.str] variable_value: The value to assign to the session variable.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RoleParameterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a system parameter in Materialize.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # ALTER ROLE some_role SET transaction_isolation = 'strict serializable';
        example_role = materialize.Role("exampleRole")
        example_role_parameter = materialize.RoleParameter("exampleRoleParameter",
            role_name=example_role.name,
            variable_name="transaction_isolation",
            variable_value="strict serializable")
        ```

        :param str resource_name: The name of the resource.
        :param RoleParameterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleParameterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 role_name: Optional[pulumi.Input[_builtins.str]] = None,
                 variable_name: Optional[pulumi.Input[_builtins.str]] = None,
                 variable_value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleParameterArgs.__new__(RoleParameterArgs)

            __props__.__dict__["region"] = region
            if role_name is None and not opts.urn:
                raise TypeError("Missing required property 'role_name'")
            __props__.__dict__["role_name"] = role_name
            if variable_name is None and not opts.urn:
                raise TypeError("Missing required property 'variable_name'")
            __props__.__dict__["variable_name"] = variable_name
            if variable_value is None and not opts.urn:
                raise TypeError("Missing required property 'variable_value'")
            __props__.__dict__["variable_value"] = variable_value
        super(RoleParameter, __self__).__init__(
            'materialize:index/roleParameter:RoleParameter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            role_name: Optional[pulumi.Input[_builtins.str]] = None,
            variable_name: Optional[pulumi.Input[_builtins.str]] = None,
            variable_value: Optional[pulumi.Input[_builtins.str]] = None) -> 'RoleParameter':
        """
        Get an existing RoleParameter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] role_name: The name of the role to grant privilege to.
        :param pulumi.Input[_builtins.str] variable_name: The name of the session variable to modify.
        :param pulumi.Input[_builtins.str] variable_value: The value to assign to the session variable.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleParameterState.__new__(_RoleParameterState)

        __props__.__dict__["region"] = region
        __props__.__dict__["role_name"] = role_name
        __props__.__dict__["variable_name"] = variable_name
        __props__.__dict__["variable_value"] = variable_value
        return RoleParameter(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the role to grant privilege to.
        """
        return pulumi.get(self, "role_name")

    @_builtins.property
    @pulumi.getter(name="variableName")
    def variable_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the session variable to modify.
        """
        return pulumi.get(self, "variable_name")

    @_builtins.property
    @pulumi.getter(name="variableValue")
    def variable_value(self) -> pulumi.Output[_builtins.str]:
        """
        The value to assign to the session variable.
        """
        return pulumi.get(self, "variable_value")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetUsersResult',
    'AwaitableGetUsersResult',
    'get_users',
    'get_users_output',
]

@pulumi.output_type
class GetUsersResult:
    """
    A collection of values returned by GetUsers.
    """
    def __init__(__self__, email=None, id=None, verified=None):
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if verified and not isinstance(verified, bool):
            raise TypeError("Expected argument 'verified' to be a bool")
        pulumi.set(__self__, "verified", verified)

    @_builtins.property
    @pulumi.getter
    def email(self) -> _builtins.str:
        """
        The email address of the user to retrieve.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique (UUID) identifier of the user.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def verified(self) -> _builtins.bool:
        """
        Whether the user's email address has been verified.
        """
        return pulumi.get(self, "verified")


class AwaitableGetUsersResult(GetUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUsersResult(
            email=self.email,
            id=self.id,
            verified=self.verified)


def get_users(email: Optional[_builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUsersResult:
    """
    The user data source allows you to retrieve information about a user in your Materialize organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    example_user = materialize.get_users(email="example@example.com")
    ```


    :param _builtins.str email: The email address of the user to retrieve.
    """
    __args__ = dict()
    __args__['email'] = email
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getUsers:GetUsers', __args__, opts=opts, typ=GetUsersResult).value

    return AwaitableGetUsersResult(
        email=pulumi.get(__ret__, 'email'),
        id=pulumi.get(__ret__, 'id'),
        verified=pulumi.get(__ret__, 'verified'))
def get_users_output(email: Optional[pulumi.Input[_builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUsersResult]:
    """
    The user data source allows you to retrieve information about a user in your Materialize organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    example_user = materialize.get_users(email="example@example.com")
    ```


    :param _builtins.str email: The email address of the user to retrieve.
    """
    __args__ = dict()
    __args__['email'] = email
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('materialize:index/getUsers:GetUsers', __args__, opts=opts, typ=GetUsersResult)
    return __ret__.apply(lambda __response__: GetUsersResult(
        email=pulumi.get(__response__, 'email'),
        id=pulumi.get(__response__, 'id'),
        verified=pulumi.get(__response__, 'verified')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SourceSqlserverArgs', 'SourceSqlserver']

@pulumi.input_type
class SourceSqlserverArgs:
    def __init__(__self__, *,
                 sqlserver_connection: pulumi.Input['SourceSqlserverSqlserverConnectionArgs'],
                 aws_privatelink: Optional[pulumi.Input['SourceSqlserverAwsPrivatelinkArgs']] = None,
                 cluster_name: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 exclude_columns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 expose_progress: Optional[pulumi.Input['SourceSqlserverExposeProgressArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ownership_role: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input['SourceSqlserverTableArgs']]]] = None,
                 text_columns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a SourceSqlserver resource.
        :param pulumi.Input['SourceSqlserverSqlserverConnectionArgs'] sqlserver_connection: The SQL Server connection to use in the source.
        :param pulumi.Input['SourceSqlserverAwsPrivatelinkArgs'] aws_privatelink: The AWS PrivateLink configuration for the SQL Server database.
        :param pulumi.Input[_builtins.str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] exclude_columns: Exclude specific columns when reading data from SQL Server. Can only be updated in place when also updating a corresponding `table` attribute.
        :param pulumi.Input['SourceSqlserverExposeProgressArgs'] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[_builtins.str] name: The identifier for the source.
        :param pulumi.Input[_builtins.str] ownership_role: The owernship role of the object.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[Sequence[pulumi.Input['SourceSqlserverTableArgs']]] tables: Specify the tables to be included in the source. If not specified, all tables are included.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] text_columns: Decode data as text for specific columns that contain SQL Server types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        pulumi.set(__self__, "sqlserver_connection", sqlserver_connection)
        if aws_privatelink is not None:
            pulumi.set(__self__, "aws_privatelink", aws_privatelink)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if exclude_columns is not None:
            pulumi.set(__self__, "exclude_columns", exclude_columns)
        if expose_progress is not None:
            pulumi.set(__self__, "expose_progress", expose_progress)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if tables is not None:
            pulumi.set(__self__, "tables", tables)
        if text_columns is not None:
            pulumi.set(__self__, "text_columns", text_columns)

    @_builtins.property
    @pulumi.getter(name="sqlserverConnection")
    def sqlserver_connection(self) -> pulumi.Input['SourceSqlserverSqlserverConnectionArgs']:
        """
        The SQL Server connection to use in the source.
        """
        return pulumi.get(self, "sqlserver_connection")

    @sqlserver_connection.setter
    def sqlserver_connection(self, value: pulumi.Input['SourceSqlserverSqlserverConnectionArgs']):
        pulumi.set(self, "sqlserver_connection", value)

    @_builtins.property
    @pulumi.getter(name="awsPrivatelink")
    def aws_privatelink(self) -> Optional[pulumi.Input['SourceSqlserverAwsPrivatelinkArgs']]:
        """
        The AWS PrivateLink configuration for the SQL Server database.
        """
        return pulumi.get(self, "aws_privatelink")

    @aws_privatelink.setter
    def aws_privatelink(self, value: Optional[pulumi.Input['SourceSqlserverAwsPrivatelinkArgs']]):
        pulumi.set(self, "aws_privatelink", value)

    @_builtins.property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_name", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "database_name", value)

    @_builtins.property
    @pulumi.getter(name="excludeColumns")
    def exclude_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Exclude specific columns when reading data from SQL Server. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        return pulumi.get(self, "exclude_columns")

    @exclude_columns.setter
    def exclude_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "exclude_columns", value)

    @_builtins.property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> Optional[pulumi.Input['SourceSqlserverExposeProgressArgs']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @expose_progress.setter
    def expose_progress(self, value: Optional[pulumi.Input['SourceSqlserverExposeProgressArgs']]):
        pulumi.set(self, "expose_progress", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ownership_role", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "schema_name", value)

    @_builtins.property
    @pulumi.getter
    def tables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SourceSqlserverTableArgs']]]]:
        """
        Specify the tables to be included in the source. If not specified, all tables are included.
        """
        return pulumi.get(self, "tables")

    @tables.setter
    def tables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SourceSqlserverTableArgs']]]]):
        pulumi.set(self, "tables", value)

    @_builtins.property
    @pulumi.getter(name="textColumns")
    def text_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Decode data as text for specific columns that contain SQL Server types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        return pulumi.get(self, "text_columns")

    @text_columns.setter
    def text_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "text_columns", value)


@pulumi.input_type
class _SourceSqlserverState:
    def __init__(__self__, *,
                 aws_privatelink: Optional[pulumi.Input['SourceSqlserverAwsPrivatelinkArgs']] = None,
                 cluster_name: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 exclude_columns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 expose_progress: Optional[pulumi.Input['SourceSqlserverExposeProgressArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ownership_role: Optional[pulumi.Input[_builtins.str]] = None,
                 qualified_sql_name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                 size: Optional[pulumi.Input[_builtins.str]] = None,
                 sqlserver_connection: Optional[pulumi.Input['SourceSqlserverSqlserverConnectionArgs']] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input['SourceSqlserverTableArgs']]]] = None,
                 text_columns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering SourceSqlserver resources.
        :param pulumi.Input['SourceSqlserverAwsPrivatelinkArgs'] aws_privatelink: The AWS PrivateLink configuration for the SQL Server database.
        :param pulumi.Input[_builtins.str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] exclude_columns: Exclude specific columns when reading data from SQL Server. Can only be updated in place when also updating a corresponding `table` attribute.
        :param pulumi.Input['SourceSqlserverExposeProgressArgs'] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[_builtins.str] name: The identifier for the source.
        :param pulumi.Input[_builtins.str] ownership_role: The owernship role of the object.
        :param pulumi.Input[_builtins.str] qualified_sql_name: The fully qualified name of the source.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[_builtins.str] size: The size of the cluster maintaining this source.
        :param pulumi.Input['SourceSqlserverSqlserverConnectionArgs'] sqlserver_connection: The SQL Server connection to use in the source.
        :param pulumi.Input[Sequence[pulumi.Input['SourceSqlserverTableArgs']]] tables: Specify the tables to be included in the source. If not specified, all tables are included.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] text_columns: Decode data as text for specific columns that contain SQL Server types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        if aws_privatelink is not None:
            pulumi.set(__self__, "aws_privatelink", aws_privatelink)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if exclude_columns is not None:
            pulumi.set(__self__, "exclude_columns", exclude_columns)
        if expose_progress is not None:
            pulumi.set(__self__, "expose_progress", expose_progress)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if sqlserver_connection is not None:
            pulumi.set(__self__, "sqlserver_connection", sqlserver_connection)
        if tables is not None:
            pulumi.set(__self__, "tables", tables)
        if text_columns is not None:
            pulumi.set(__self__, "text_columns", text_columns)

    @_builtins.property
    @pulumi.getter(name="awsPrivatelink")
    def aws_privatelink(self) -> Optional[pulumi.Input['SourceSqlserverAwsPrivatelinkArgs']]:
        """
        The AWS PrivateLink configuration for the SQL Server database.
        """
        return pulumi.get(self, "aws_privatelink")

    @aws_privatelink.setter
    def aws_privatelink(self, value: Optional[pulumi.Input['SourceSqlserverAwsPrivatelinkArgs']]):
        pulumi.set(self, "aws_privatelink", value)

    @_builtins.property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_name", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "database_name", value)

    @_builtins.property
    @pulumi.getter(name="excludeColumns")
    def exclude_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Exclude specific columns when reading data from SQL Server. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        return pulumi.get(self, "exclude_columns")

    @exclude_columns.setter
    def exclude_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "exclude_columns", value)

    @_builtins.property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> Optional[pulumi.Input['SourceSqlserverExposeProgressArgs']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @expose_progress.setter
    def expose_progress(self, value: Optional[pulumi.Input['SourceSqlserverExposeProgressArgs']]):
        pulumi.set(self, "expose_progress", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ownership_role", value)

    @_builtins.property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The fully qualified name of the source.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "schema_name", value)

    @_builtins.property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The size of the cluster maintaining this source.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "size", value)

    @_builtins.property
    @pulumi.getter(name="sqlserverConnection")
    def sqlserver_connection(self) -> Optional[pulumi.Input['SourceSqlserverSqlserverConnectionArgs']]:
        """
        The SQL Server connection to use in the source.
        """
        return pulumi.get(self, "sqlserver_connection")

    @sqlserver_connection.setter
    def sqlserver_connection(self, value: Optional[pulumi.Input['SourceSqlserverSqlserverConnectionArgs']]):
        pulumi.set(self, "sqlserver_connection", value)

    @_builtins.property
    @pulumi.getter
    def tables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SourceSqlserverTableArgs']]]]:
        """
        Specify the tables to be included in the source. If not specified, all tables are included.
        """
        return pulumi.get(self, "tables")

    @tables.setter
    def tables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SourceSqlserverTableArgs']]]]):
        pulumi.set(self, "tables", value)

    @_builtins.property
    @pulumi.getter(name="textColumns")
    def text_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Decode data as text for specific columns that contain SQL Server types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        return pulumi.get(self, "text_columns")

    @text_columns.setter
    def text_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "text_columns", value)


@pulumi.type_token("materialize:index/sourceSqlserver:SourceSqlserver")
class SourceSqlserver(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_privatelink: Optional[pulumi.Input[Union['SourceSqlserverAwsPrivatelinkArgs', 'SourceSqlserverAwsPrivatelinkArgsDict']]] = None,
                 cluster_name: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 exclude_columns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 expose_progress: Optional[pulumi.Input[Union['SourceSqlserverExposeProgressArgs', 'SourceSqlserverExposeProgressArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ownership_role: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sqlserver_connection: Optional[pulumi.Input[Union['SourceSqlserverSqlserverConnectionArgs', 'SourceSqlserverSqlserverConnectionArgsDict']]] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SourceSqlserverTableArgs', 'SourceSqlserverTableArgsDict']]]]] = None,
                 text_columns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        A SQL Server source describes a SQL Server database instance you want Materialize to read data from using Change Data Capture (CDC).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        sqlserver_password = materialize.Secret("sqlserverPassword",
            value="some-secret-value",
            comment="secret comment")
        sqlserver_connection = materialize.ConnectionSqlserver("sqlserverConnection",
            host="sql-server.example.com",
            port=1433,
            user={
                "text": "sqluser",
            },
            password={
                "name": sqlserver_password.name,
                "schema_name": sqlserver_password.schema_name,
                "database_name": sqlserver_password.database_name,
            },
            database="testdb")
        # Basic SQL Server source for specific tables
        example = materialize.SourceSqlserver("example",
            cluster_name="quickstart",
            sqlserver_connection={
                "name": sqlserver_connection.name,
                "schema_name": sqlserver_connection.schema_name,
                "database_name": sqlserver_connection.database_name,
            },
            tables=[
                {
                    "upstream_name": "dbo.customers",
                    "name": "customers",
                },
                {
                    "upstream_name": "dbo.orders",
                    "name": "orders",
                },
                {
                    "upstream_name": "dbo.products",
                    "name": "products",
                },
            ])
        # SQL Server source for all tables
        all_tables = materialize.SourceSqlserver("allTables",
            cluster_name="quickstart",
            sqlserver_connection={
                "name": sqlserver_connection.name,
                "schema_name": sqlserver_connection.schema_name,
                "database_name": sqlserver_connection.database_name,
            })
        # No table blocks specified means all tables will be included
        # SQL Server source with text columns and excluded columns
        with_options = materialize.SourceSqlserver("withOptions",
            cluster_name="quickstart",
            sqlserver_connection={
                "name": sqlserver_connection.name,
                "schema_name": sqlserver_connection.schema_name,
                "database_name": sqlserver_connection.database_name,
            },
            tables=[
                {
                    "upstream_name": "dbo.users",
                    "name": "users",
                },
                {
                    "upstream_name": "dbo.posts",
                    "name": "posts",
                },
                {
                    "upstream_name": "dbo.comments",
                    "name": "comments",
                },
            ],
            text_columns=[
                "dbo.users.description",
                "dbo.posts.content",
                "dbo.comments.metadata",
            ],
            exclude_columns=[
                "dbo.users.image_data",
                "dbo.posts.binary_data",
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        #!/bin/bash

        SQL Server sources can be imported using the source name

        ```sh
        $ pulumi import materialize:index/sourceSqlserver:SourceSqlserver example <region>:<source_name>
        ```

        Example

        ```sh
        $ pulumi import materialize:index/sourceSqlserver:SourceSqlserver example aws/us-east-1:my_sqlserver_source
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['SourceSqlserverAwsPrivatelinkArgs', 'SourceSqlserverAwsPrivatelinkArgsDict']] aws_privatelink: The AWS PrivateLink configuration for the SQL Server database.
        :param pulumi.Input[_builtins.str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] exclude_columns: Exclude specific columns when reading data from SQL Server. Can only be updated in place when also updating a corresponding `table` attribute.
        :param pulumi.Input[Union['SourceSqlserverExposeProgressArgs', 'SourceSqlserverExposeProgressArgsDict']] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[_builtins.str] name: The identifier for the source.
        :param pulumi.Input[_builtins.str] ownership_role: The owernship role of the object.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[Union['SourceSqlserverSqlserverConnectionArgs', 'SourceSqlserverSqlserverConnectionArgsDict']] sqlserver_connection: The SQL Server connection to use in the source.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SourceSqlserverTableArgs', 'SourceSqlserverTableArgsDict']]]] tables: Specify the tables to be included in the source. If not specified, all tables are included.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] text_columns: Decode data as text for specific columns that contain SQL Server types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SourceSqlserverArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A SQL Server source describes a SQL Server database instance you want Materialize to read data from using Change Data Capture (CDC).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        sqlserver_password = materialize.Secret("sqlserverPassword",
            value="some-secret-value",
            comment="secret comment")
        sqlserver_connection = materialize.ConnectionSqlserver("sqlserverConnection",
            host="sql-server.example.com",
            port=1433,
            user={
                "text": "sqluser",
            },
            password={
                "name": sqlserver_password.name,
                "schema_name": sqlserver_password.schema_name,
                "database_name": sqlserver_password.database_name,
            },
            database="testdb")
        # Basic SQL Server source for specific tables
        example = materialize.SourceSqlserver("example",
            cluster_name="quickstart",
            sqlserver_connection={
                "name": sqlserver_connection.name,
                "schema_name": sqlserver_connection.schema_name,
                "database_name": sqlserver_connection.database_name,
            },
            tables=[
                {
                    "upstream_name": "dbo.customers",
                    "name": "customers",
                },
                {
                    "upstream_name": "dbo.orders",
                    "name": "orders",
                },
                {
                    "upstream_name": "dbo.products",
                    "name": "products",
                },
            ])
        # SQL Server source for all tables
        all_tables = materialize.SourceSqlserver("allTables",
            cluster_name="quickstart",
            sqlserver_connection={
                "name": sqlserver_connection.name,
                "schema_name": sqlserver_connection.schema_name,
                "database_name": sqlserver_connection.database_name,
            })
        # No table blocks specified means all tables will be included
        # SQL Server source with text columns and excluded columns
        with_options = materialize.SourceSqlserver("withOptions",
            cluster_name="quickstart",
            sqlserver_connection={
                "name": sqlserver_connection.name,
                "schema_name": sqlserver_connection.schema_name,
                "database_name": sqlserver_connection.database_name,
            },
            tables=[
                {
                    "upstream_name": "dbo.users",
                    "name": "users",
                },
                {
                    "upstream_name": "dbo.posts",
                    "name": "posts",
                },
                {
                    "upstream_name": "dbo.comments",
                    "name": "comments",
                },
            ],
            text_columns=[
                "dbo.users.description",
                "dbo.posts.content",
                "dbo.comments.metadata",
            ],
            exclude_columns=[
                "dbo.users.image_data",
                "dbo.posts.binary_data",
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        #!/bin/bash

        SQL Server sources can be imported using the source name

        ```sh
        $ pulumi import materialize:index/sourceSqlserver:SourceSqlserver example <region>:<source_name>
        ```

        Example

        ```sh
        $ pulumi import materialize:index/sourceSqlserver:SourceSqlserver example aws/us-east-1:my_sqlserver_source
        ```

        :param str resource_name: The name of the resource.
        :param SourceSqlserverArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SourceSqlserverArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_privatelink: Optional[pulumi.Input[Union['SourceSqlserverAwsPrivatelinkArgs', 'SourceSqlserverAwsPrivatelinkArgsDict']]] = None,
                 cluster_name: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 exclude_columns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 expose_progress: Optional[pulumi.Input[Union['SourceSqlserverExposeProgressArgs', 'SourceSqlserverExposeProgressArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ownership_role: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sqlserver_connection: Optional[pulumi.Input[Union['SourceSqlserverSqlserverConnectionArgs', 'SourceSqlserverSqlserverConnectionArgsDict']]] = None,
                 tables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SourceSqlserverTableArgs', 'SourceSqlserverTableArgsDict']]]]] = None,
                 text_columns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SourceSqlserverArgs.__new__(SourceSqlserverArgs)

            __props__.__dict__["aws_privatelink"] = aws_privatelink
            __props__.__dict__["cluster_name"] = cluster_name
            __props__.__dict__["comment"] = comment
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["exclude_columns"] = exclude_columns
            __props__.__dict__["expose_progress"] = expose_progress
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["region"] = region
            __props__.__dict__["schema_name"] = schema_name
            if sqlserver_connection is None and not opts.urn:
                raise TypeError("Missing required property 'sqlserver_connection'")
            __props__.__dict__["sqlserver_connection"] = sqlserver_connection
            __props__.__dict__["tables"] = tables
            __props__.__dict__["text_columns"] = text_columns
            __props__.__dict__["qualified_sql_name"] = None
            __props__.__dict__["size"] = None
        super(SourceSqlserver, __self__).__init__(
            'materialize:index/sourceSqlserver:SourceSqlserver',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aws_privatelink: Optional[pulumi.Input[Union['SourceSqlserverAwsPrivatelinkArgs', 'SourceSqlserverAwsPrivatelinkArgsDict']]] = None,
            cluster_name: Optional[pulumi.Input[_builtins.str]] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            database_name: Optional[pulumi.Input[_builtins.str]] = None,
            exclude_columns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            expose_progress: Optional[pulumi.Input[Union['SourceSqlserverExposeProgressArgs', 'SourceSqlserverExposeProgressArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            ownership_role: Optional[pulumi.Input[_builtins.str]] = None,
            qualified_sql_name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            schema_name: Optional[pulumi.Input[_builtins.str]] = None,
            size: Optional[pulumi.Input[_builtins.str]] = None,
            sqlserver_connection: Optional[pulumi.Input[Union['SourceSqlserverSqlserverConnectionArgs', 'SourceSqlserverSqlserverConnectionArgsDict']]] = None,
            tables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SourceSqlserverTableArgs', 'SourceSqlserverTableArgsDict']]]]] = None,
            text_columns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'SourceSqlserver':
        """
        Get an existing SourceSqlserver resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['SourceSqlserverAwsPrivatelinkArgs', 'SourceSqlserverAwsPrivatelinkArgsDict']] aws_privatelink: The AWS PrivateLink configuration for the SQL Server database.
        :param pulumi.Input[_builtins.str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.str] database_name: The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] exclude_columns: Exclude specific columns when reading data from SQL Server. Can only be updated in place when also updating a corresponding `table` attribute.
        :param pulumi.Input[Union['SourceSqlserverExposeProgressArgs', 'SourceSqlserverExposeProgressArgsDict']] expose_progress: The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        :param pulumi.Input[_builtins.str] name: The identifier for the source.
        :param pulumi.Input[_builtins.str] ownership_role: The owernship role of the object.
        :param pulumi.Input[_builtins.str] qualified_sql_name: The fully qualified name of the source.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] schema_name: The identifier for the source schema in Materialize. Defaults to `public`.
        :param pulumi.Input[_builtins.str] size: The size of the cluster maintaining this source.
        :param pulumi.Input[Union['SourceSqlserverSqlserverConnectionArgs', 'SourceSqlserverSqlserverConnectionArgsDict']] sqlserver_connection: The SQL Server connection to use in the source.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SourceSqlserverTableArgs', 'SourceSqlserverTableArgsDict']]]] tables: Specify the tables to be included in the source. If not specified, all tables are included.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] text_columns: Decode data as text for specific columns that contain SQL Server types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SourceSqlserverState.__new__(_SourceSqlserverState)

        __props__.__dict__["aws_privatelink"] = aws_privatelink
        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["comment"] = comment
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["exclude_columns"] = exclude_columns
        __props__.__dict__["expose_progress"] = expose_progress
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["size"] = size
        __props__.__dict__["sqlserver_connection"] = sqlserver_connection
        __props__.__dict__["tables"] = tables
        __props__.__dict__["text_columns"] = text_columns
        return SourceSqlserver(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="awsPrivatelink")
    def aws_privatelink(self) -> pulumi.Output[Optional['outputs.SourceSqlserverAwsPrivatelink']]:
        """
        The AWS PrivateLink configuration for the SQL Server database.
        """
        return pulumi.get(self, "aws_privatelink")

    @_builtins.property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[_builtins.str]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The identifier for the source database in Materialize. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @_builtins.property
    @pulumi.getter(name="excludeColumns")
    def exclude_columns(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Exclude specific columns when reading data from SQL Server. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        return pulumi.get(self, "exclude_columns")

    @_builtins.property
    @pulumi.getter(name="exposeProgress")
    def expose_progress(self) -> pulumi.Output[Optional['outputs.SourceSqlserverExposeProgress']]:
        """
        The name of the progress collection for the source. If this is not specified, the collection will be named `<src_name>_progress`.
        """
        return pulumi.get(self, "expose_progress")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[_builtins.str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @_builtins.property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[_builtins.str]:
        """
        The fully qualified name of the source.
        """
        return pulumi.get(self, "qualified_sql_name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The identifier for the source schema in Materialize. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @_builtins.property
    @pulumi.getter
    def size(self) -> pulumi.Output[_builtins.str]:
        """
        The size of the cluster maintaining this source.
        """
        return pulumi.get(self, "size")

    @_builtins.property
    @pulumi.getter(name="sqlserverConnection")
    def sqlserver_connection(self) -> pulumi.Output['outputs.SourceSqlserverSqlserverConnection']:
        """
        The SQL Server connection to use in the source.
        """
        return pulumi.get(self, "sqlserver_connection")

    @_builtins.property
    @pulumi.getter
    def tables(self) -> pulumi.Output[Sequence['outputs.SourceSqlserverTable']]:
        """
        Specify the tables to be included in the source. If not specified, all tables are included.
        """
        return pulumi.get(self, "tables")

    @_builtins.property
    @pulumi.getter(name="textColumns")
    def text_columns(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Decode data as text for specific columns that contain SQL Server types that are unsupported in Materialize. Can only be updated in place when also updating a corresponding `table` attribute.
        """
        return pulumi.get(self, "text_columns")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkPolicyArgs', 'NetworkPolicy']

@pulumi.input_type
class NetworkPolicyArgs:
    def __init__(__self__, *,
                 rules: pulumi.Input[Sequence[pulumi.Input['NetworkPolicyRuleArgs']]],
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a NetworkPolicy resource.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkPolicyRuleArgs']]] rules: Rules for the network policy.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.str] name: The name of the network policy.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        """
        pulumi.set(__self__, "rules", rules)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> pulumi.Input[Sequence[pulumi.Input['NetworkPolicyRuleArgs']]]:
        """
        Rules for the network policy.
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: pulumi.Input[Sequence[pulumi.Input['NetworkPolicyRuleArgs']]]):
        pulumi.set(self, "rules", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the network policy.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _NetworkPolicyState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPolicyRuleArgs']]]] = None):
        """
        Input properties used for looking up and filtering NetworkPolicy resources.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.str] name: The name of the network policy.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[Sequence[pulumi.Input['NetworkPolicyRuleArgs']]] rules: Rules for the network policy.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the network policy.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPolicyRuleArgs']]]]:
        """
        Rules for the network policy.
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPolicyRuleArgs']]]]):
        pulumi.set(self, "rules", value)


@pulumi.type_token("materialize:index/networkPolicy:NetworkPolicy")
class NetworkPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkPolicyRuleArgs', 'NetworkPolicyRuleArgsDict']]]]] = None,
                 __props__=None):
        """
        A network policy manages access to the system through IP-based rules.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        office_policy = materialize.NetworkPolicy("officePolicy",
            comment="Network policy for office locations",
            rules=[
                {
                    "action": "allow",
                    "address": "2.3.4.5/32",
                    "direction": "ingress",
                    "name": "minnesota",
                },
                {
                    "action": "allow",
                    "address": "1.2.3.4/28",
                    "direction": "ingress",
                    "name": "new_york",
                },
            ])
        # An initial `default` network policy will be created.
        # This policy allows open access to the environment and can be altered by a `superuser`.
        # Use the `ALTER SYSTEM SET network_policy TO 'office_access_policy'` command.
        # Or the `materialize_system_parameter` resource to set the default network policy.
        system_parameter = materialize.SystemParameter("systemParameter", value="office_access_policy")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Network policies can be imported using the `pulumi import` command.

        ```sh
        $ pulumi import materialize:index/networkPolicy:NetworkPolicy example_network_policy <region>:<network_policy_id>
        ```

        The network_policy_id is the ID of the network policy.

        You can find it from the `mz_internal.mz_network_policy_rules` table in the materialize

        The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.str] name: The name of the network policy.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NetworkPolicyRuleArgs', 'NetworkPolicyRuleArgsDict']]]] rules: Rules for the network policy.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A network policy manages access to the system through IP-based rules.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        office_policy = materialize.NetworkPolicy("officePolicy",
            comment="Network policy for office locations",
            rules=[
                {
                    "action": "allow",
                    "address": "2.3.4.5/32",
                    "direction": "ingress",
                    "name": "minnesota",
                },
                {
                    "action": "allow",
                    "address": "1.2.3.4/28",
                    "direction": "ingress",
                    "name": "new_york",
                },
            ])
        # An initial `default` network policy will be created.
        # This policy allows open access to the environment and can be altered by a `superuser`.
        # Use the `ALTER SYSTEM SET network_policy TO 'office_access_policy'` command.
        # Or the `materialize_system_parameter` resource to set the default network policy.
        system_parameter = materialize.SystemParameter("systemParameter", value="office_access_policy")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Network policies can be imported using the `pulumi import` command.

        ```sh
        $ pulumi import materialize:index/networkPolicy:NetworkPolicy example_network_policy <region>:<network_policy_id>
        ```

        The network_policy_id is the ID of the network policy.

        You can find it from the `mz_internal.mz_network_policy_rules` table in the materialize

        The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param NetworkPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkPolicyRuleArgs', 'NetworkPolicyRuleArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkPolicyArgs.__new__(NetworkPolicyArgs)

            __props__.__dict__["comment"] = comment
            __props__.__dict__["name"] = name
            __props__.__dict__["region"] = region
            if rules is None and not opts.urn:
                raise TypeError("Missing required property 'rules'")
            __props__.__dict__["rules"] = rules
        super(NetworkPolicy, __self__).__init__(
            'materialize:index/networkPolicy:NetworkPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkPolicyRuleArgs', 'NetworkPolicyRuleArgsDict']]]]] = None) -> 'NetworkPolicy':
        """
        Get an existing NetworkPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.str] name: The name of the network policy.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NetworkPolicyRuleArgs', 'NetworkPolicyRuleArgsDict']]]] rules: Rules for the network policy.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkPolicyState.__new__(_NetworkPolicyState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["rules"] = rules
        return NetworkPolicy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the network policy.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Sequence['outputs.NetworkPolicyRule']]:
        """
        Rules for the network policy.
        """
        return pulumi.get(self, "rules")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ClusterReplicaArgs', 'ClusterReplica']

@pulumi.input_type
class ClusterReplicaArgs:
    def __init__(__self__, *,
                 cluster_name: pulumi.Input[_builtins.str],
                 size: pulumi.Input[_builtins.str],
                 availability_zone: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 disk: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_debugging: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ClusterReplica resource.
        :param pulumi.Input[_builtins.str] cluster_name: The cluster whose resources you want to create an additional computation of.
        :param pulumi.Input[_builtins.str] size: The size of the replica.
        :param pulumi.Input[_builtins.str] availability_zone: The specific availability zone of the replica.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.bool] disk: **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        :param pulumi.Input[_builtins.bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[_builtins.str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[_builtins.str] name: The identifier for the replica.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        """
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "size", size)
        if availability_zone is not None:
            pulumi.set(__self__, "availability_zone", availability_zone)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if disk is not None:
            warnings.warn("""Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""", DeprecationWarning)
            pulumi.log.warn("""disk is deprecated: Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""")
        if disk is not None:
            pulumi.set(__self__, "disk", disk)
        if introspection_debugging is not None:
            pulumi.set(__self__, "introspection_debugging", introspection_debugging)
        if introspection_interval is not None:
            pulumi.set(__self__, "introspection_interval", introspection_interval)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Input[_builtins.str]:
        """
        The cluster whose resources you want to create an additional computation of.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cluster_name", value)

    @_builtins.property
    @pulumi.getter
    def size(self) -> pulumi.Input[_builtins.str]:
        """
        The size of the replica.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "size", value)

    @_builtins.property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The specific availability zone of the replica.
        """
        return pulumi.get(self, "availability_zone")

    @availability_zone.setter
    def availability_zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "availability_zone", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""")
    def disk(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        """
        return pulumi.get(self, "disk")

    @disk.setter
    def disk(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disk", value)

    @_builtins.property
    @pulumi.getter(name="introspectionDebugging")
    def introspection_debugging(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to introspect the gathering of the introspection data.
        """
        return pulumi.get(self, "introspection_debugging")

    @introspection_debugging.setter
    def introspection_debugging(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "introspection_debugging", value)

    @_builtins.property
    @pulumi.getter(name="introspectionInterval")
    def introspection_interval(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The interval at which to collect introspection data.
        """
        return pulumi.get(self, "introspection_interval")

    @introspection_interval.setter
    def introspection_interval(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "introspection_interval", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the replica.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _ClusterReplicaState:
    def __init__(__self__, *,
                 availability_zone: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_name: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 disk: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_debugging: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 size: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ClusterReplica resources.
        :param pulumi.Input[_builtins.str] availability_zone: The specific availability zone of the replica.
        :param pulumi.Input[_builtins.str] cluster_name: The cluster whose resources you want to create an additional computation of.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.bool] disk: **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        :param pulumi.Input[_builtins.bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[_builtins.str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[_builtins.str] name: The identifier for the replica.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] size: The size of the replica.
        """
        if availability_zone is not None:
            pulumi.set(__self__, "availability_zone", availability_zone)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if disk is not None:
            warnings.warn("""Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""", DeprecationWarning)
            pulumi.log.warn("""disk is deprecated: Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""")
        if disk is not None:
            pulumi.set(__self__, "disk", disk)
        if introspection_debugging is not None:
            pulumi.set(__self__, "introspection_debugging", introspection_debugging)
        if introspection_interval is not None:
            pulumi.set(__self__, "introspection_interval", introspection_interval)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if size is not None:
            pulumi.set(__self__, "size", size)

    @_builtins.property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The specific availability zone of the replica.
        """
        return pulumi.get(self, "availability_zone")

    @availability_zone.setter
    def availability_zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "availability_zone", value)

    @_builtins.property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cluster whose resources you want to create an additional computation of.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_name", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""")
    def disk(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        """
        return pulumi.get(self, "disk")

    @disk.setter
    def disk(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disk", value)

    @_builtins.property
    @pulumi.getter(name="introspectionDebugging")
    def introspection_debugging(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to introspect the gathering of the introspection data.
        """
        return pulumi.get(self, "introspection_debugging")

    @introspection_debugging.setter
    def introspection_debugging(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "introspection_debugging", value)

    @_builtins.property
    @pulumi.getter(name="introspectionInterval")
    def introspection_interval(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The interval at which to collect introspection data.
        """
        return pulumi.get(self, "introspection_interval")

    @introspection_interval.setter
    def introspection_interval(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "introspection_interval", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the replica.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The size of the replica.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "size", value)


@pulumi.type_token("materialize:index/clusterReplica:ClusterReplica")
class ClusterReplica(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 availability_zone: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_name: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 disk: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_debugging: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 size: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Cluster replicas allocate physical compute resources for a cluster.

        *Note*: Cluster replicas are deprecated. We recommend migrating to a managed cluster using the `Cluster` resource and selecting `size`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_cluster_replica = materialize.ClusterReplica("exampleClusterReplica",
            cluster_name="cluster",
            size="2xsmall")
        ```

        ## Import

        Cluster replicas can be imported using the cluster replica id:

        ```sh
        $ pulumi import materialize:index/clusterReplica:ClusterReplica example_1_cluster_replica <region>:<cluster_replica_id>
        ```

        Cluster replica id and information be found in the `mz_catalog.mz_cluster_replicas` table

        The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] availability_zone: The specific availability zone of the replica.
        :param pulumi.Input[_builtins.str] cluster_name: The cluster whose resources you want to create an additional computation of.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.bool] disk: **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        :param pulumi.Input[_builtins.bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[_builtins.str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[_builtins.str] name: The identifier for the replica.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] size: The size of the replica.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterReplicaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Cluster replicas allocate physical compute resources for a cluster.

        *Note*: Cluster replicas are deprecated. We recommend migrating to a managed cluster using the `Cluster` resource and selecting `size`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_cluster_replica = materialize.ClusterReplica("exampleClusterReplica",
            cluster_name="cluster",
            size="2xsmall")
        ```

        ## Import

        Cluster replicas can be imported using the cluster replica id:

        ```sh
        $ pulumi import materialize:index/clusterReplica:ClusterReplica example_1_cluster_replica <region>:<cluster_replica_id>
        ```

        Cluster replica id and information be found in the `mz_catalog.mz_cluster_replicas` table

        The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param ClusterReplicaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterReplicaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 availability_zone: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_name: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 disk: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_debugging: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 size: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterReplicaArgs.__new__(ClusterReplicaArgs)

            __props__.__dict__["availability_zone"] = availability_zone
            if cluster_name is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_name'")
            __props__.__dict__["cluster_name"] = cluster_name
            __props__.__dict__["comment"] = comment
            __props__.__dict__["disk"] = disk
            __props__.__dict__["introspection_debugging"] = introspection_debugging
            __props__.__dict__["introspection_interval"] = introspection_interval
            __props__.__dict__["name"] = name
            __props__.__dict__["region"] = region
            if size is None and not opts.urn:
                raise TypeError("Missing required property 'size'")
            __props__.__dict__["size"] = size
        super(ClusterReplica, __self__).__init__(
            'materialize:index/clusterReplica:ClusterReplica',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            availability_zone: Optional[pulumi.Input[_builtins.str]] = None,
            cluster_name: Optional[pulumi.Input[_builtins.str]] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            disk: Optional[pulumi.Input[_builtins.bool]] = None,
            introspection_debugging: Optional[pulumi.Input[_builtins.bool]] = None,
            introspection_interval: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            size: Optional[pulumi.Input[_builtins.str]] = None) -> 'ClusterReplica':
        """
        Get an existing ClusterReplica resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] availability_zone: The specific availability zone of the replica.
        :param pulumi.Input[_builtins.str] cluster_name: The cluster whose resources you want to create an additional computation of.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.bool] disk: **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        :param pulumi.Input[_builtins.bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[_builtins.str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[_builtins.str] name: The identifier for the replica.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] size: The size of the replica.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterReplicaState.__new__(_ClusterReplicaState)

        __props__.__dict__["availability_zone"] = availability_zone
        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["comment"] = comment
        __props__.__dict__["disk"] = disk
        __props__.__dict__["introspection_debugging"] = introspection_debugging
        __props__.__dict__["introspection_interval"] = introspection_interval
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["size"] = size
        return ClusterReplica(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> pulumi.Output[_builtins.str]:
        """
        The specific availability zone of the replica.
        """
        return pulumi.get(self, "availability_zone")

    @_builtins.property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[_builtins.str]:
        """
        The cluster whose resources you want to create an additional computation of.
        """
        return pulumi.get(self, "cluster_name")

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""")
    def disk(self) -> pulumi.Output[_builtins.bool]:
        """
        **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        """
        return pulumi.get(self, "disk")

    @_builtins.property
    @pulumi.getter(name="introspectionDebugging")
    def introspection_debugging(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to introspect the gathering of the introspection data.
        """
        return pulumi.get(self, "introspection_debugging")

    @_builtins.property
    @pulumi.getter(name="introspectionInterval")
    def introspection_interval(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The interval at which to collect introspection data.
        """
        return pulumi.get(self, "introspection_interval")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The identifier for the replica.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def size(self) -> pulumi.Output[_builtins.str]:
        """
        The size of the replica.
        """
        return pulumi.get(self, "size")

